@@ -141,22 +141,24 @@ color_data = {
 
 async def set_infoparams(List):
     try:
-        winsColor = await set_winColor(int(List['pvp']['wins']))
-        damageColor = await set_damageColor(None,int(List['pvp']['damage']))
-        bb_winsColor = await set_winColor(int(List['type']['Battleship']['wins']))
-        ca_winsColor = await set_winColor(int(List['type']['Cruiser']['wins']))
-        dd_winsColor = await set_winColor(int(List['type']['Destroyer']['wins']))
-        cv_winsColor = await set_winColor(int(List['type']['AirCarrier']['wins']))
-        bb_damageColor = await set_damageColor(None,int(List['type']['Battleship']['damage']))
-        ca_damageColor = await set_damageColor('Cruiser',int(List['type']['Cruiser']['damage']))
-        dd_damageColor = await set_damageColor('Destroyer',int(List['type']['Destroyer']['damage']))
-        cv_damageColor = await set_damageColor('AirCarrier',int(List['type']['AirCarrier']['damage']))
-        solo_winsColor = await set_winColor(int(List['pvpSolo']['wins']))
-        solo_damageColor = await set_damageColor(None,int(List['pvpSolo']['damage']))
-        div2_winsColor = await set_winColor(int(List['pvpTwo']['wins']))
-        div2_damageColor = await set_damageColor(None,int(List['pvpTwo']['damage']))
-        div3_winsColor = await set_winColor(int(List['pvpThree']['wins']))
-        div3_damageColor = await set_damageColor(None,int(List['pvpThree']['damage']))
+        winsColor = await set_winColor(List['pvp']['wins'])
+        damageColor = await set_damageColor(None,List['pvp']['damage'])
+        bb_winsColor = await set_winColor(List['type']['Battleship']['wins'])
+        ca_winsColor = await set_winColor(List['type']['Cruiser']['wins'])
+        dd_winsColor = await set_winColor(List['type']['Destroyer']['wins'])
+        cv_winsColor = await set_winColor(List['type']['AirCarrier']['wins'])
+        bb_damageColor = await set_damageColor(None,List['type']['Battleship']['damage'])
+        ca_damageColor = await set_damageColor('Cruiser',List['type']['Cruiser']['damage'])
+        dd_damageColor = await set_damageColor('Destroyer',List['type']['Destroyer']['damage'])
+        cv_damageColor = await set_damageColor('AirCarrier',List['type']['AirCarrier']['damage'])
+        solo_winsColor = await set_winColor(List['pvpSolo']['wins'])
+        solo_damageColor = await set_damageColor(None,List['pvpSolo']['damage'])
+        div2_winsColor = await set_winColor(List['pvpTwo']['wins'])
+        div2_damageColor = await set_damageColor(None,List['pvpTwo']['damage'])
+        div3_winsColor = await set_winColor(List['pvpThree']['wins'])
+        div3_damageColor = await set_damageColor(None,List['pvpThree']['damage'])
+        rank_winsColor = await set_winColor(List['rankSolo']['wins'])
+        rank_damageColor = await set_damageColor(None,List['rankSolo']['damage'])
         newDamageColor = await set_upinfo_color(List['dwpDataVO']['damage'])
         newWinsColor = await set_upinfo_color(List['dwpDataVO']['wins'])
         newPrColor = await set_upinfo_color(List['dwpDataVO']['pr'])
@@ -169,7 +171,7 @@ async def set_infoparams(List):
             "newWins":f"{List['dwpDataVO']['wins']:+.2f}",
             "newPr":f"{List['dwpDataVO']['pr']:+}",
             "prValue":f"{List['pr']['value']} {List['pr']['name']}",
-            "time":time.strftime('%Y-%m-%d %H:%M:%S',time.localtime(List['lastDateTime'])),
+            "time":time.strftime('%Y-%m-%d %H:%M:%S',time.localtime(abs(List['lastDateTime']))),
             "battles":List['pvp']['battles'],
             "wins":List['pvp']['wins'],
             "damage":List['pvp']['damage'],
@@ -214,6 +216,12 @@ async def set_infoparams(List):
             "div3_damage":List['pvpThree']['damage'],
             "div3_kd":List['pvpThree']['kd'],
             "div3_hit":List['pvpThree']['hit'],
+            "rank_battles":List['rankSolo']['battles'],
+            "rank_wins":List['rankSolo']['wins'],
+            "rank_xp":List['rankSolo']['xp'],
+            "rank_damage":List['rankSolo']['damage'],
+            "rank_kd":List['rankSolo']['kd'],
+            "rank_hit":List['rankSolo']['hit'],
             "lv1":List['battleCountAll']['1'],
             "lv2":List['battleCountAll']['2'],
             "lv3":List['battleCountAll']['3'],
@@ -248,7 +256,9 @@ async def set_infoparams(List):
             "div2_winsColor":div2_winsColor,
             "div2_damageColor":div2_damageColor,
             "div3_winsColor":div3_winsColor,
-            "div3_damageColor":div3_damageColor
+            "div3_damageColor":div3_damageColor,
+            "rank_winsColor":rank_winsColor,
+            "rank_damageColor":rank_damageColor
         }
         return result
     except Exception:
@@ -257,14 +267,14 @@ async def set_infoparams(List):
 async def set_recentparams(List):
     try:   
         historyData = await set_historyData(List['recentList'])
-        winsColor = await set_winColor(int(List['data']['wins']))
-        damageColor = await set_damageColor(None,int(List['data']['damage']))
+        winsColor = await set_winColor(List['data']['wins'])
+        damageColor = await set_damageColor(None,List['data']['damage'])
         result = {
             "guild":List['clanInfo']['tag'],
             "userName":List['userName'],
             "serverName":List['serverName'],
             "prValue":f"{List['data']['pr']['value']} {List['data']['pr']['name']}",
-            "reTime":time.strftime('%Y-%m-%d %H:%M:%S',time.localtime(List['recordTime'])),
+            "reTime":time.strftime('%Y-%m-%d %H:%M:%S',time.localtime(abs(List['recordTime']))),
             "battles":List['data']['battles'],
             "wins":List['data']['wins'],
             "damage":List['data']['damage'],
@@ -285,20 +295,55 @@ async def set_shipparams(List):
         damageTopColor = await set_upinfo_color(List['dwpDataVO']['damage'])
         winsTopColor = await set_upinfo_color(List['dwpDataVO']['wins'])
         prTopColor = await set_upinfo_color(List['dwpDataVO']['pr'])
+        solo_winsColor = await set_winColor(List['shipSolo']['wins'])
+        solo_damageColor = await set_damageColor(None,List['shipSolo']['damage'])
+        div2_winsColor = await set_winColor(List['shipTwo']['wins'])
+        div2_damageColor = await set_damageColor(None,List['shipTwo']['damage'])
+        div3_winsColor = await set_winColor(List['shipThree']['wins'])
+        div3_damageColor = await set_damageColor(None,List['shipThree']['damage'])
+        rank_winsColor = await set_winColor(List['rankSolo']['wins'])
+        rank_damageColor = await set_damageColor(None,List['rankSolo']['damage'])
         result = {
+            "guild":List['clanInfo']['tag'],
+            "userName":List['userName'],
+            "serverName":List['serverName'],
             "shipNameEn":List['shipInfo']['shipInfo']['nameEnglish'],
             "shipNameCn":List['shipInfo']['shipInfo']['nameCn'],
             "damageTop":f"{List['dwpDataVO']['damage']:+}",
             "winsTop":f"{List['dwpDataVO']['wins']:+.2f}",
             "prTop":f"{List['dwpDataVO']['pr']:+}",
             "prValue":f"{List['shipInfo']['pr']['value']} {List['shipInfo']['pr']['name']}",
-            "lastTime":time.strftime('%Y-%m-%d %H:%M:%S',time.localtime(List['shipInfo']['lastBattlesTime'])),
+            "lastTime":time.strftime('%Y-%m-%d %H:%M:%S',time.localtime(abs(List['shipInfo']['lastBattlesTime']))),
             "battles":List['shipInfo']['battles'],
             "wins":List['shipInfo']['wins'],
             "damage":List['shipInfo']['damage'],
             "xp":List['shipInfo']['xp'],
             "kda":List['shipInfo']['kd'],
             "hit":List['shipInfo']['hit'],
+            "solo_battles":List['shipSolo']['battles'],
+            "solo_wins":List['shipSolo']['wins'],
+            "solo_xp":List['shipSolo']['xp'],
+            "solo_damage":List['shipSolo']['damage'],
+            "solo_kd":List['shipSolo']['kd'],
+            "solo_hit":List['shipSolo']['hit'],
+            "div2_battles":List['shipTwo']['battles'],
+            "div2_wins":List['shipTwo']['wins'],
+            "div2_xp":List['shipTwo']['xp'],
+            "div2_damage":List['shipTwo']['damage'],
+            "div2_kd":List['shipTwo']['kd'],
+            "div2_hit":List['shipTwo']['hit'],
+            "div3_battles":List['shipThree']['battles'],
+            "div3_wins":List['shipThree']['wins'],
+            "div3_xp":List['shipThree']['xp'],
+            "div3_damage":List['shipThree']['damage'],
+            "div3_kd":List['shipThree']['kd'],
+            "div3_hit":List['shipThree']['hit'],
+            "rank_battles":List['rankSolo']['battles'],
+            "rank_wins":List['rankSolo']['wins'],
+            "rank_xp":List['rankSolo']['xp'],
+            "rank_damage":List['rankSolo']['damage'],
+            "rank_kd":List['rankSolo']['kd'],
+            "rank_hit":List['rankSolo']['hit'],
             "maxDamage":List['shipInfo']['extensionDataInfo']['maxDamage'],
             "maxDamageScouting":List['shipInfo']['extensionDataInfo']['maxDamageScouting'],
             "maxTotalAgro":List['shipInfo']['extensionDataInfo']['maxTotalAgro'],
@@ -308,13 +353,20 @@ async def set_shipparams(List):
             "prColor":List['shipInfo']['pr']['color'],
             "damageTopColor":damageTopColor,
             "winsTopColor":winsTopColor,
-            "prTopColor":prTopColor
+            "prTopColor":prTopColor,
+            "solo_winsColor":solo_winsColor,
+            "solo_damageColor":solo_damageColor,
+            "div2_winsColor":div2_winsColor,
+            "div2_damageColor":div2_damageColor,
+            "div3_winsColor":div3_winsColor,
+            "div3_damageColor":div3_damageColor,
+            "rank_winsColor":rank_winsColor,
+            "rank_damageColor":rank_damageColor
         }
         return result
     except Exception:
         traceback.print_exc()
 
-
 async def select_prvalue_and_color(pr:int):
     for select in pr_select :
         if pr > select['value']:
@@ -326,87 +378,97 @@ async def set_historyData(List):
     historyData = ''
     for ship in List:
         historyData += r'<tr>'
-        historyData += r'<td class="blueColor">'+f"{ship['shipInfo']['nameCn']}"+r'</td>'
-        historyData += r'<td class="blueColor">'+f"{ship['shipInfo']['level']}"+r'</td>'
-        historyData += r'<td class="blueColor">'+f"{ship['battles']}"+r'</td>'
-        historyData += f'''<td class="blueColor" style="color: {ship['pr']['color']}">{ship['pr']['value']} {ship['pr']['name']}</td>'''
-        historyData += r'<td class="blueColor">'+f"{ship['xp']}"+r'</td>'
-        wincolor = await set_winColor(int(ship['wins']))
-        historyData += f'''<td class="blueColor" style="color: {wincolor}">{ship['wins']}%</td>'''
-        damagecolor = await set_damageColor(ship['shipInfo']['shipType'],int(ship['damage']))
-        historyData += f'''<td class="blueColor" style="color: {damagecolor}">{ship['damage']}</td>'''
-        historyData += r'<td class="blueColor">'+f"{ship['hit']}%"+r'</td>'
+        historyData += r'<td colspan="8" class="blueColor">'+f"{ship['shipInfo']['nameCn']}"+r'</td>'
+        historyData += r'<td colspan="3" class="blueColor">'+f"{ship['shipInfo']['level']}"+r'</td>'
+        historyData += r'<td colspan="3" class="blueColor">'+f"{ship['battles']}"+r'</td>'
+        historyData += f'''<td colspan="7" class="blueColor" style="color: {ship['pr']['color']}">{ship['pr']['value']} {ship['pr']['name']}</td>'''
+        historyData += r'<td colspan="4" class="blueColor">'+f"{ship['xp']}"+r'</td>'
+        wincolor = await set_winColor(ship['wins'])
+        historyData += f'''<td class="blueColor" colspan="5" style="color: {wincolor}">{ship['wins']}%</td>'''
+        damagecolor = await set_damageColor(ship['shipInfo']['shipType'],ship['damage'])
+        historyData += f'''<td colspan="5" class="blueColor" style="color: {damagecolor}">{ship['damage']}</td>'''
+        historyData += r'<td colspan="5" class="blueColor">'+f"{ship['hit']}%"+r'</td>'
         historyData += r'</tr>'
     return historyData
 
-async def set_damageColor(type:str,value:int):
-    if type == 'Destroyer':
-        if value < 33000:
-            return color_data["Bad"]
-        elif value < 40000:
-            return color_data["Good"]
-        elif value < 55000:
-            return color_data["Great"]
-        elif value < 64000:
-            return color_data["Unicum"]
+async def set_damageColor(type,value):
+    try:
+        if type == 'Destroyer':
+            if not value or value < 33000:
+                return color_data["Bad"]
+            elif value < 40000:
+                return color_data["Good"]
+            elif value < 55000:
+                return color_data["Great"]
+            elif value < 64000:
+                return color_data["Unicum"]
+            else:
+                return color_data["Super Unicum"]
+        elif type == 'Cruiser':
+            if not value or value < 47000:
+                return color_data["Bad"]
+            elif value < 55000:
+                return color_data["Good"]
+            elif value < 83000:
+                return color_data["Great"]
+            elif value < 95000:
+                return color_data["Unicum"]
+            else:
+                return color_data["Super Unicum"]
+        elif type == 'AirCarrier':
+            if not value or value < 60000:
+                return color_data["Bad"]
+            elif value < 71000:
+                return color_data["Good"]
+            elif value < 84000:
+                return color_data["Great"]
+            elif value < 113000:
+                return color_data["Unicum"]
+            else:
+                return color_data["Super Unicum"]
         else:
-            return color_data["Super Unicum"]
-    elif type == 'Cruiser':
-        if value < 47000:
-            return color_data["Bad"]
-        elif value < 55000:
-            return color_data["Good"]
-        elif value < 83000:
-            return color_data["Great"]
-        elif value < 95000:
-            return color_data["Unicum"]
-        else:
-            return color_data["Super Unicum"]
-    elif type == 'AirCarrier':
-        if value < 60000:
-            return color_data["Bad"]
-        elif value < 71000:
-            return color_data["Good"]
-        elif value < 84000:
-            return color_data["Great"]
-        elif value < 113000:
-            return color_data["Unicum"]
-        else:
-            return color_data["Super Unicum"]
-    else:
-        if value < 64000:
-            return color_data["Bad"]
-        elif value < 72000:
-            return color_data["Good"]
-        elif value < 97000:
-            return color_data["Great"]
-        elif value < 108000:
-            return color_data["Unicum"]
-        else:
-            return color_data["Super Unicum"]
-    return None
+            if not value or value < 64000:
+                return color_data["Bad"]
+            elif value < 72000:
+                return color_data["Good"]
+            elif value < 97000:
+                return color_data["Great"]
+            elif value < 108000:
+                return color_data["Unicum"]
+            else:
+                return color_data["Super Unicum"]
+    except Exception:
+        traceback.print_exc()
+        return None
 
-async def set_winColor(value:int):
-    if value < 45:
-        return color_data["Bad"]
-    elif value < 50:
-        return color_data["Below Average"]
-    elif value < 55:
-        return color_data["Average"]
-    elif value < 60:
-        return color_data["Good"]
-    elif value < 65:
-        return color_data["Great"]
-    elif value < 70:
-        return color_data["Unicum"]
-    else:
-        return color_data["Super Unicum"]
-    return None
+async def set_winColor(value):
+    try:
+        if not value or value < 45:
+            return color_data["Bad"]
+        elif value < 50:
+            return color_data["Below Average"]
+        elif value < 55:
+            return color_data["Average"]
+        elif value < 60:
+            return color_data["Good"]
+        elif value < 65:
+            return color_data["Great"]
+        elif value < 70:
+            return color_data["Unicum"]
+        else:
+            return color_data["Super Unicum"]
+    except Exception:
+        traceback.print_exc()
+        return None
 
-async def set_upinfo_color(value:int):
-    if value < 0 :
-        return color_data["Bad"]
-    elif value > 0 :
-        return color_data["Good"]
-    else:
+async def set_upinfo_color(value):
+    try:
+        if not value or value < 0 :
+            return color_data["Bad"]
+        elif value > 0 :
+            return color_data["Good"]
+        else:
+            return None
+    except Exception:
+        traceback.print_exc()
         return None
\ No newline at end of file
