@@ -6,12 +6,11 @@ import jinja2
 import re
 from pathlib import Path
 from .data_source import servers,set_infoparams
-from .utils import match_keywords,encode_gzip
+from .utils import match_keywords
 from .publicAPI import get_AccountIdByName
 from nonebot_plugin_htmlrender import html_to_pic
 from nonebot import get_driver
 from nonebot.log import logger
-import json
 
 dir_path = Path(__file__).parent
 template_path = dir_path / "template"
